@@ -169,12 +169,13 @@ def build_include_fields_function(
             for field_name in field_names
         ]
     )
-    names_params_str = "" if not names_params else f", {names_params}"
+    if not names_params:
+        return ""
     s = f"""
-def include_fields(self, *other_fields: str{names_params_str}) -> {node_resolver_name}:
-    fields_to_include: set[str] = set(other_fields)
+def include(self, *, {names_params}) -> {node_resolver_name}:
+    fields_to_include: set[str] = set()
 {indent_lines(logic_strs)}
-    return super().include_fields(*fields_to_include)
+    return self.include_fields(*fields_to_include)
     """
     return s
 
