@@ -37,8 +37,10 @@ class DependencyInfo(BaseModel):
     ignore_if_admin: bool
     ignore_if_no_auth_id: bool
     require_user: bool
-
-    edge: str  # name of edge using
+    # name of edge using
+    edge: str
+    # resolver instead of any
+    required_nested_resolver_f_map: dict[str, set[T.Callable]] = {}
 
 
 FieldDepMapAlias = T.Dict[str, DependencyInfo]
@@ -138,6 +140,25 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             cls.set_field_dependency_map(dict())
         return cls._field_dependency_map
 
+    @classmethod
+    def add_required_nested_resolver(
+        cls, field: str, edge: str, resolver_f: callable
+    ) -> None:
+        # TODO need all this dependency info shit? -> it is really resolver dependent
+        if field not in cls.field_dependency_map:
+            cls.field_dependency_map[field] = DependencyInfo(
+                fields=set(),
+                ignore_if_admin=False,
+                ignore_if_no_auth_id=False,
+                require_user=False,
+                edge=field,
+            )
+        prev_dep_info: DependencyInfo = cls.field_dependency_map[field]
+        f_map = prev_dep_info.required_nested_resolver_f_map
+        if edge not in f_map:
+            f_map[edge] = set()
+        f_map[edge].add(resolver_f)
+
     @classmethod
     def upsert_dependency_info(cls, field: str, dep_info: DependencyInfo) -> None:
         if getattr(cls, "_field_dependency_map", None) is None:
